<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LinetypeSettings</name>
    <message>
        <location filename="../LinetypeSettings.js" line="+25"/>
        <source>Defaults for New Drawings</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Domyślne dla nowych rysunków</translatorcomment>
        <translation>Domyślne dla nowych rysunków</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Linetype</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rodzaj linii</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>General</source>
        <translatorcomment>--google--
Ogólne ustawienia aplikacji
[2000-206F] General Punctuation
General Punctuation</translatorcomment>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Global Linetype Scale:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ogólna skala rodzaju linii:</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Scale of linetypes matches the scale of each viewport</source>
        <translation>Dopasowanie skali rodzaju linii do skali rzutni</translation>
    </message>
</context>
</TS>
